# PowerProfile

![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python2.7-app.yml/badge.svg)

![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python3.6-app.yml/badge.svg)
![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python3.7-app.yml/badge.svg)
![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python3.8-app.yml/badge.svg)
![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python3.9-app.yml/badge.svg)
![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python3.10-app.yml/badge.svg)
![Build Status](https://github.com/gisce/powerprofile/actions/workflows/python3.11-app.yml/badge.svg)

Electric Power Curve and Profiles library

Libray to manipulate easily profiles and operate with and between them
